#[non_exhaustive]pub struct Event {
pub bcs: Option<BcsData>,
pub package_id: Option<ObjectId>,
pub module: Option<String>,
pub sender: Option<Address>,
pub event_type: Option<String>,
pub bcs_contents: Option<BcsData>,
pub json_contents: Option<Value>,
}Expand description
An event.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.bcs: Option<BcsData>This Event serialized as BCS.
package_id: Option<ObjectId>Package ID of the top-level function invoked by a MoveCall command that triggered this
event to be emitted.
module: Option<String>Module name of the top-level function invoked by a MoveCall command that triggered this
event to be emitted.
sender: Option<Address>Address of the account that sent the transaction where this event was emitted.
event_type: Option<String>The type of the event emitted.
bcs_contents: Option<BcsData>BCS serialized bytes of the event.
json_contents: Option<Value>JSON rendering of the event.
Implementations
Sourceimpl Event
impl Event
pub const BCS_FIELD: &'static MessageField
pub const PACKAGE_ID_FIELD: &'static MessageField
pub const MODULE_FIELD: &'static MessageField
pub const SENDER_FIELD: &'static MessageField
pub const EVENT_TYPE_FIELD: &'static MessageField
pub const BCS_CONTENTS_FIELD: &'static MessageField
pub const JSON_CONTENTS_FIELD: &'static MessageField
Sourceimpl Event
impl Event
pub fn path_builder() -> EventFieldPathBuilder
Sourceimpl Event
impl Event
Sourcepub fn with_package_id<T: Into<ObjectId>>(self, field: T) -> Self
pub fn with_package_id<T: Into<ObjectId>>(self, field: T) -> Self
Sets package_id with the provided value.
Sourcepub fn with_module<T: Into<String>>(self, field: T) -> Self
pub fn with_module<T: Into<String>>(self, field: T) -> Self
Sets module with the provided value.
Sourcepub fn with_sender<T: Into<Address>>(self, field: T) -> Self
pub fn with_sender<T: Into<Address>>(self, field: T) -> Self
Sets sender with the provided value.
Sourcepub fn with_event_type<T: Into<String>>(self, field: T) -> Self
pub fn with_event_type<T: Into<String>>(self, field: T) -> Self
Sets event_type with the provided value.
Sourcepub fn with_bcs_contents<T: Into<BcsData>>(self, field: T) -> Self
pub fn with_bcs_contents<T: Into<BcsData>>(self, field: T) -> Self
Sets bcs_contents with the provided value.
Sourcepub fn with_json_contents<T: Into<Value>>(self, field: T) -> Self
pub fn with_json_contents<T: Into<Value>>(self, field: T) -> Self
Sets json_contents with the provided value.
Sourceimpl Event
impl Event
Sourcepub fn event(&self) -> Result<Event, TryFromProtoError>
pub fn event(&self) -> Result<Event, TryFromProtoError>
Deserialize the full event from BCS.
Read mask: bcs relative to this event (see EVENT_BCS).
Full path depends on context — e.g. "events.bcs" for checkpoint
top-level events, "events.events.bcs" for transaction events.
Sourcepub fn package_id(&self) -> Result<ObjectId, TryFromProtoError>
pub fn package_id(&self) -> Result<ObjectId, TryFromProtoError>
Get the package ID of the Move module that emitted this event.
Read mask: package_id relative to this event (see
EVENT_PACKAGE_ID).
Sourcepub fn module_name(&self) -> Result<Identifier, TryFromProtoError>
pub fn module_name(&self) -> Result<Identifier, TryFromProtoError>
Get the module name of the Move module that emitted this event.
Read mask: module relative to this event (see EVENT_MODULE).
Sourcepub fn sender(&self) -> Result<Address, TryFromProtoError>
pub fn sender(&self) -> Result<Address, TryFromProtoError>
Get the sender address of the transaction that emitted this event.
Read mask: sender relative to this event (see EVENT_SENDER).
Sourcepub fn type_name(&self) -> Result<StructTag, TryFromProtoError>
pub fn type_name(&self) -> Result<StructTag, TryFromProtoError>
Get the type of the event emitted.
Read mask: event_type relative to this event (see
EVENT_TYPE).
Sourcepub fn bcs_contents(&self) -> Result<&[u8], TryFromProtoError>
pub fn bcs_contents(&self) -> Result<&[u8], TryFromProtoError>
Get the raw BCS bytes of the event contents/data only.
This is the serialized event data without the metadata (package, module, sender, type).
Read mask: bcs_contents relative to this event (see
EVENT_BCS_CONTENTS).
Sourcepub fn json_contents(&self) -> Result<Value, TryFromProtoError>
pub fn json_contents(&self) -> Result<Value, TryFromProtoError>
Get the JSON contents of the event.
Read mask: json_contents relative to this event (see
EVENT_JSON_CONTENTS).